        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 18 <br>2,4,8,9,14,20,22,27,31,32,33,34,37,39,40,41,42,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 16 <br>3,5,6,12,16,17,18,21,25,30,35,36,43,45,46,47';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <strong>control</strong><br>0,7,15,19,24,26,28,38,48';}
       if(rr==6 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>49</strong> miembros: 8 <br>1,10,11,13,23,29,44,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 18 <br>2,4,8,9,14,20,22,27,31,32,33,34,37,39,40,41,42,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 16 <br>3,5,6,12,16,17,18,21,25,30,35,36,43,45,46,47';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <strong>control</strong><br>0,7,15,19,24,26,28,38,48';}
       if(rr==29 && cc==4){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>49</strong> miembros: 8 <br>1,10,11,13,23,29,44,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 18 <br>2,4,8,9,14,20,22,27,31,32,33,34,37,39,40,41,42,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 16 <br>3,5,6,12,16,17,18,21,25,30,35,36,43,45,46,47';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <strong>control</strong><br>0,7,15,19,24,26,28,38,48';}
       if(rr==30 && cc==4){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>49</strong> miembros: 8 <br>1,10,11,13,23,29,44,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 18 <br>2,4,8,9,14,20,22,27,31,32,33,34,37,39,40,41,42,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 16 <br>3,5,6,12,16,17,18,21,25,30,35,36,43,45,46,47';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <strong>control</strong><br>0,7,15,19,24,26,28,38,48';}
       if(rr==31 && cc==4){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>49</strong> miembros: 8 <br>1,10,11,13,23,29,44,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 18 <br>2,4,8,9,14,20,22,27,31,32,33,34,37,39,40,41,42,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 16 <br>3,5,6,12,16,17,18,21,25,30,35,36,43,45,46,47';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <strong>control</strong><br>0,7,15,19,24,26,28,38,48';}
       if(rr==32 && cc==4){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>49</strong> miembros: 8 <br>1,10,11,13,23,29,44,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 18 <br>2,4,8,9,14,20,22,27,31,32,33,34,37,39,40,41,42,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 16 <br>3,5,6,12,16,17,18,21,25,30,35,36,43,45,46,47';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 9 <strong>control</strong><br>0,7,15,19,24,26,28,38,48';}
       if(rr==33 && cc==4){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260611 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>49</strong> miembros: 8 <br>1,10,11,13,23,29,44,49';}
}
